/// <reference types="node" />
import { FileLoader } from './FileLoader';
import '@dcfjs/common/noCaptureEnv';
import { TempStorageSession } from './../common/storageRegistry';
import { RDD } from './RDD';
import { Client } from '@dcfjs/common/client';
import { FunctionEnv } from '@dcfjs/common';
export interface ContextOption {
    showProgress: boolean;
    defaultPartitions: number;
    defaultPersistStorage: string;
    defaultRepartitionStorage: string;
}
export declare class Context {
    private _client;
    private _option;
    private _fileLoaders;
    constructor(client: Client, option?: Partial<ContextOption>);
    readonly client: Client;
    readonly option: ContextOption;
    registerFileLoader(loader: FileLoader): void;
    close(): Promise<void>;
    execute<T, T1, T2 = any>(numPartitions: number, partitionFunc: (paritionId: number, tempStorageSession: TempStorageSession) => ((workerId: string) => T | Promise<T>) | ([(workerId: string) => T2 | Promise<T2>, (arg: T2) => T | Promise<T>]), // first function run on worker, second function run on master
    finalFunc: (v: T[], tempStorageSession: TempStorageSession) => T1 | Promise<T1>): Promise<T1>;
    emptyRDD(): RDD<never>;
    range(to: number): RDD<number>;
    range(from: number, to?: number, step?: number, numPartitions?: number): RDD<number>;
    parallelize<T>(arr: T[], numPartitions?: number): RDD<T>;
    union<T>(...rdds: RDD<T>[]): RDD<T>;
    getFileLoader(baseUri: string): FileLoader | undefined;
    binaryFiles(baseUri: string, { recursive, }?: {
        recursive?: boolean;
    }): RDD<[string, Buffer]>;
    wholeTextFiles(baseUrl: string, { decompressor, encoding, recursive, functionEnv, }?: {
        encoding?: string;
        recursive?: boolean;
        decompressor?: (data: Buffer, filename: string) => Buffer;
        functionEnv?: FunctionEnv;
    }): RDD<[string, string]>;
    textFile(baseUrl: string, options?: {
        encoding?: string;
        recursive?: boolean;
        decompressor?: (data: Buffer, filename: string) => Buffer;
        functionEnv?: FunctionEnv;
        __dangerousDontCopy?: boolean;
    }): RDD<string>;
}
export declare function createContext(masterEndpoint: string): Promise<Context>;
